@@ -1,7 +1,7 @@
 /*
  * @(#)Abacus.h
  *
- * Copyright 1994 - 2012  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2014  David A. Bagley, bagleyd@tux.org
  *
  * Abacus demo and neat pointers from
  * Copyright 1991 - 1998  Luis Fernandes, elf@ee.ryerson.ca
@@ -49,6 +49,7 @@
 #define XtNhighlightRailColor ((char *) "highlightRailColor")
 #define XtNbumpSound ((char *) "bumpSound")
 #define XtNmoveSound ((char *) "moveSound")
+#define XtNdripSound ((char *) "dripSound")
 #define XtNsound ((char *) "sound")
 #define XtNdelay ((char *) "delay")
 #define XtNscript ((char *) "script")
@@ -131,6 +132,7 @@
 #define XtCHighlightRailColor ((char *) "HighlightRailColor")
 #define XtCBumpSound ((char *) "BumpSound")
 #define XtCMoveSound ((char *) "MoveSound")
+#define XtCDripSound ((char *) "DripSound")
 #define XtCSound ((char *) "Sound")
 #define XtCDelay ((char *) "Delay")
 #define XtCScript ((char *) "Script")
@@ -339,6 +341,7 @@ typedef struct {
 #define MAX_MODES 7
 #define TEACH_STRING0 "Enter calculation X+Y, X-Y, X*Y, X/Y, Xv, or Xu where X positive and result positive."
 #define TEACH_STRING1 "Press enter to go through calculation steps."
+#define ZERO_STRING "0.0"
 
 typedef struct _AbacusRec *AbacusWidget;
 typedef struct _AbacusRec *AbacusDemoWidget;
