@@ -1,7 +1,7 @@
 /*
  * @(#)AbacusP.h
  *
- * Copyright 1994 - 2013  David A. Bagley, bagleyd@tux.org
+ * Copyright 1994 - 2014  David A. Bagley, bagleyd@tux.org
  *
  * Abacus demo and neat pointers from
  * Copyright 1991 - 1998  Luis Fernandes, elf@ee.ryerson.ca
@@ -58,7 +58,7 @@ extern void initializeAbacus(AbacusWidget w, HBRUSH brush);
 extern void exposeAbacus(AbacusWidget w);
 extern void hideAbacus(AbacusWidget w);
 extern void selectAbacus(AbacusWidget w, const int x, const int y);
-extern void releaseAbacus(AbacusWidget w);
+extern void releaseAbacus(AbacusWidget w, const int x, const int y);
 extern void clearAbacus(AbacusWidget w);
 extern void complementAbacus(AbacusWidget w);
 extern void incrementAbacus(AbacusWidget w);
@@ -131,6 +131,9 @@ extern AbacusClassRec abacusClassRec;
 #ifndef MOVESOUND
 #define MOVESOUND "move"
 #endif
+#ifndef DRIPSOUND
+#define DRIPSOUND "drip"
+#endif
 
 #define MAX_DECKS 2
 #define PLACE_SETTING 2
@@ -214,7 +217,7 @@ typedef struct _AbacusPart {
 	int         leftAuxRails, rightAuxRails;
 	int         aux, deck, rail, number;
 	int         pressOffsetX, pressOffsetY;
-	Position    width, midHeight, midBarY, railWidth;
+	Position    width, middleBarHeight, middleBarPositionY, railWidth;
 	Point       frameSize, beadSize;
 	Point       pos, delta, offset;
 	Boolean     sign, minusSign, romanNumerals, group, decimalComma;
@@ -240,13 +243,13 @@ typedef struct _AbacusPart {
 	struct _AbacusPart *leftAux, *rightAux;
 #ifdef WINVER
 	char        format[STRING_SIZE], museum[COUNTRY_SIZE];
-	char        bumpSound[STRING_SIZE], moveSound[STRING_SIZE];
+	char        bumpSound[STRING_SIZE], moveSound[STRING_SIZE], dripSound[STRING_SIZE];
 	char        aString[STRING_SIZE], bString[STRING_SIZE];
 	char        cString[STRING_SIZE], rString[STRING_SIZE];
 	char        sString[STRING_SIZE];
 	char        helperBuffer[STRING_SIZE];
 #else
-	char       *format, *museum, *bumpSound, *moveSound;
+	char       *format, *museum, *bumpSound, *moveSound, *dripSound;
 	char       *aString, *bString, *cString, *rString, *sString;
 	char       *teachBuffer;
 	int         menu, pixmapSize;
@@ -325,7 +328,6 @@ extern int convertBaseToBottom(int base);
 extern int rootInt(int i, int n);
 
 extern void clearRails(AbacusWidget w);
-extern void clearAuxRails(AbacusWidget w, int aux);
 extern void addBackAnomaly(char * buf, int anomaly, int shift, int base);
 extern void zeroFractionalPart(char * buf);
 extern void convertStringToAbacus(AbacusWidget w, char *string, int aux);
@@ -335,6 +337,8 @@ extern void convertFromDouble(char *outputString, int base, double x);
 #ifdef WINVER
 extern void drawDemoText(const char* line, int i);
 extern void drawTeachText(const char* line, int i);
+#else
+extern void clearAuxRails(AbacusWidget w, int aux);
 #endif
 
 #endif /* _AbacusP_h */
